package com.nokia.financeapi.service.house;

import com.nokia.financeapi.common.R;
import com.nokia.financeapi.dao.house.HouseReportDao;
import com.nokia.financeapi.pojo.dto.GetHouseReportDto;
import com.nokia.financeapi.pojo.po.house.HouseReportsPo;
import com.nokia.financeapi.pojo.vo.GetHouseReportVo;
import com.nokia.financeapi.service.common.file.FileService;
import org.springframework.stereotype.Service;

@Service
public class HouseReportService {
    private final FileService fileService;
    private final HouseReportDao houseReportDao;

    public HouseReportService(FileService fileService, HouseReportDao houseReportDao) {
        this.fileService = fileService;
        this.houseReportDao = houseReportDao;
    }

    public R<GetHouseReportVo> getReportWord(GetHouseReportDto dto) {
        dto.setFileType("word");
        return getReport(dto);
    }

    public R<GetHouseReportVo> getReportPdf(GetHouseReportDto dto) {
        dto.setFileType("pdf");
        return getReport(dto);
    }

    private R<GetHouseReportVo> getReport(GetHouseReportDto dto) {
        GetHouseReportVo vo = new GetHouseReportVo();
        vo.setUrl("");
        String object ="word".equals(dto.getFileType()) ? "oss/reports/house/default.doc"
                : "oss/reports/house/default.pdf";
        if (dto.getEndDate() == null) {
            HouseReportsPo po = houseReportDao.getLatest(dto);
            if (po != null) {
                object = po.getUrl();
            }
        } else {
            HouseReportsPo po = houseReportDao.getByDate(dto);
            if (po != null) {
                object = po.getUrl();
            }
        }
        String url = fileService.getDownloadUrl(object);
        vo.setUrl(url);
        return R.ok(vo);
    }
}
